# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List
from uuid import UUID
from authentik_client.models.content_type import ContentType
from authentik_client.models.partial_user import PartialUser
from typing import Optional, Set
from typing_extensions import Self

class DataExport(BaseModel):
    """
    Mixin to validate that a valid enterprise license exists before allowing to save the object
    """ # noqa: E501
    id: UUID
    requested_by: PartialUser
    requested_on: datetime
    content_type: ContentType
    var_query_params: Dict[str, Any] = Field(alias="query_params")
    file_url: StrictStr
    completed: StrictBool
    __properties: ClassVar[List[str]] = ["id", "requested_by", "requested_on", "content_type", "query_params", "file_url", "completed"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataExport from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "requested_by",
            "requested_on",
            "content_type",
            "file_url",
            "completed",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of requested_by
        if self.requested_by:
            _dict['requested_by'] = self.requested_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of content_type
        if self.content_type:
            _dict['content_type'] = self.content_type.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataExport from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "requested_by": PartialUser.from_dict(obj["requested_by"]) if obj.get("requested_by") is not None else None,
            "requested_on": obj.get("requested_on"),
            "content_type": ContentType.from_dict(obj["content_type"]) if obj.get("content_type") is not None else None,
            "query_params": obj.get("query_params"),
            "file_url": obj.get("file_url"),
            "completed": obj.get("completed")
        })
        return _obj


