# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from authentik_client.models.connector import Connector
from authentik_client.models.device_fact_snapshot import DeviceFactSnapshot
from typing import Optional, Set
from typing_extensions import Self

class DeviceConnection(BaseModel):
    """
    DeviceConnection
    """ # noqa: E501
    device: UUID
    connector: UUID
    connector_obj: Connector
    latest_snapshot: Optional[DeviceFactSnapshot]
    __properties: ClassVar[List[str]] = ["device", "connector", "connector_obj", "latest_snapshot"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DeviceConnection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "connector_obj",
            "latest_snapshot",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of connector_obj
        if self.connector_obj:
            _dict['connector_obj'] = self.connector_obj.to_dict()
        # override the default output from pydantic by calling `to_dict()` of latest_snapshot
        if self.latest_snapshot:
            _dict['latest_snapshot'] = self.latest_snapshot.to_dict()
        # set to None if latest_snapshot (nullable) is None
        # and model_fields_set contains the field
        if self.latest_snapshot is None and "latest_snapshot" in self.model_fields_set:
            _dict['latest_snapshot'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DeviceConnection from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "device": obj.get("device"),
            "connector": obj.get("connector"),
            "connector_obj": Connector.from_dict(obj["connector_obj"]) if obj.get("connector_obj") is not None else None,
            "latest_snapshot": DeviceFactSnapshot.from_dict(obj["latest_snapshot"]) if obj.get("latest_snapshot") is not None else None
        })
        return _obj


