# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.patched_ssf_provider_request import PatchedSSFProviderRequest

class TestPatchedSSFProviderRequest(unittest.TestCase):
    """PatchedSSFProviderRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedSSFProviderRequest:
        """Test PatchedSSFProviderRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedSSFProviderRequest`
        """
        model = PatchedSSFProviderRequest()
        if include_optional:
            return PatchedSSFProviderRequest(
                name = '0',
                signing_key = '',
                oidc_auth_providers = [
                    56
                    ],
                event_retention = '0'
            )
        else:
            return PatchedSSFProviderRequest(
        )
        """

    def testPatchedSSFProviderRequest(self):
        """Test PatchedSSFProviderRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
