# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.lifecycle_api import LifecycleApi


class TestLifecycleApi(unittest.TestCase):
    """LifecycleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LifecycleApi()

    def tearDown(self) -> None:
        pass

    def test_lifecycle_iterations_create(self) -> None:
        """Test case for lifecycle_iterations_create

        """
        pass

    def test_lifecycle_iterations_latest_retrieve(self) -> None:
        """Test case for lifecycle_iterations_latest_retrieve

        """
        pass

    def test_lifecycle_iterations_list_open(self) -> None:
        """Test case for lifecycle_iterations_list_open

        """
        pass

    def test_lifecycle_reviews_create(self) -> None:
        """Test case for lifecycle_reviews_create

        """
        pass

    def test_lifecycle_rules_create(self) -> None:
        """Test case for lifecycle_rules_create

        """
        pass

    def test_lifecycle_rules_destroy(self) -> None:
        """Test case for lifecycle_rules_destroy

        """
        pass

    def test_lifecycle_rules_list(self) -> None:
        """Test case for lifecycle_rules_list

        """
        pass

    def test_lifecycle_rules_partial_update(self) -> None:
        """Test case for lifecycle_rules_partial_update

        """
        pass

    def test_lifecycle_rules_retrieve(self) -> None:
        """Test case for lifecycle_rules_retrieve

        """
        pass

    def test_lifecycle_rules_update(self) -> None:
        """Test case for lifecycle_rules_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
