# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.email_stage_request import EmailStageRequest

class TestEmailStageRequest(unittest.TestCase):
    """EmailStageRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EmailStageRequest:
        """Test EmailStageRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EmailStageRequest`
        """
        model = EmailStageRequest()
        if include_optional:
            return EmailStageRequest(
                name = '0',
                use_global_settings = True,
                host = '0',
                port = -2147483648,
                username = '',
                password = '',
                use_tls = True,
                use_ssl = True,
                timeout = -2147483648,
                from_address = '0',
                token_expiry = '0',
                subject = '0',
                template = '0',
                activate_user_on_success = True,
                recovery_max_attempts = 0,
                recovery_cache_timeout = '0'
            )
        else:
            return EmailStageRequest(
                name = '0',
        )
        """

    def testEmailStageRequest(self):
        """Test EmailStageRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
