# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.lifecycle_iteration import LifecycleIteration

class TestLifecycleIteration(unittest.TestCase):
    """LifecycleIteration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LifecycleIteration:
        """Test LifecycleIteration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LifecycleIteration`
        """
        model = LifecycleIteration()
        if include_optional:
            return LifecycleIteration(
                id = '',
                content_type = 'authentik_core.application',
                object_id = '',
                object_verbose = '',
                object_admin_url = '',
                state = 'REVIEWED',
                opened_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                grace_period_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                next_review_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                reviews = [
                    authentik_client.models.review.Review(
                        id = '', 
                        iteration = '', 
                        reviewer = null, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        note = '', )
                    ],
                user_can_review = True,
                reviewer_groups = [
                    authentik_client.models.reviewer_group.ReviewerGroup(
                        pk = '', 
                        name = '', )
                    ],
                min_reviewers = 56,
                reviewers = [
                    authentik_client.models.reviewer_user.ReviewerUser(
                        pk = 56, 
                        uuid = '', 
                        username = 'A', 
                        name = '', )
                    ]
            )
        else:
            return LifecycleIteration(
                id = '',
                content_type = 'authentik_core.application',
                object_id = '',
                object_verbose = '',
                object_admin_url = '',
                state = 'REVIEWED',
                opened_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                grace_period_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                next_review_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                reviews = [
                    authentik_client.models.review.Review(
                        id = '', 
                        iteration = '', 
                        reviewer = null, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        note = '', )
                    ],
                user_can_review = True,
                reviewer_groups = [
                    authentik_client.models.reviewer_group.ReviewerGroup(
                        pk = '', 
                        name = '', )
                    ],
                min_reviewers = 56,
                reviewers = [
                    authentik_client.models.reviewer_user.ReviewerUser(
                        pk = 56, 
                        uuid = '', 
                        username = 'A', 
                        name = '', )
                    ],
        )
        """

    def testLifecycleIteration(self):
        """Test LifecycleIteration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
